diff --git a/Trigger/TrigSteer/L1Decoder/src/L1Decoder.h b/Trigger/TrigSteer/L1Decoder/src/L1Decoder.h
index 1e59f1412ea6b63aea393360a11bc5b8d6c6243d..073270b410f98be8cd931cac24ded2fcd25fe90d 100644
--- a/Trigger/TrigSteer/L1Decoder/src/L1Decoder.h
+++ b/Trigger/TrigSteer/L1Decoder/src/L1Decoder.h
@@ -69,7 +69,7 @@ private:
     "Enables start-of-event cost monitoring behavior."};
 
   Gaudi::Property<std::string> m_costMonitoringChain{
-    this, "CostMonitoringChain", "HLT_costmonitor_CostMonDS_L1All",
+    this, "CostMonitoringChain", "HLT_noalg_CostMonDS_L1All",
     "Name of the chain which should enable HLT cost montoring."};
 
   ServiceHandle<ITrigCostMTSvc> m_trigCostSvcHandle {
diff --git a/Trigger/TrigValidation/TrigAnalysisTest/share/ref_RDOtoRDOTrig_v1Dev_build.ref b/Trigger/TrigValidation/TrigAnalysisTest/share/ref_RDOtoRDOTrig_v1Dev_build.ref
index c65fe721af01d7713106d4ba7ea7b60d48c3cf39..9c1c51d1b254cc3d3908b0b4a056c4057fae4557 100644
--- a/Trigger/TrigValidation/TrigAnalysisTest/share/ref_RDOtoRDOTrig_v1Dev_build.ref
+++ b/Trigger/TrigValidation/TrigAnalysisTest/share/ref_RDOtoRDOTrig_v1Dev_build.ref
@@ -750,24 +750,10 @@ HLT_JetDS_j0_L1J100:
     0: 137
     1: 33
     2: 3
-HLT_alfacalib_AlfaPEB_L1ALFA_ANY:
-  eventCount: 0
 HLT_beamspot_allTE_trkfast_BeamSpotPEB_L1J15:
   eventCount: 0
 HLT_beamspot_trkFS_trkfast_BeamSpotPEB_L1J15:
   eventCount: 0
-HLT_costmonitor_CostMonDS_L1All:
-  eventCount: 20
-  stepCounts:
-    0: 20
-  stepFeatures:
-    0: 20
-HLT_cscmon_CSCPEB_L1All:
-  eventCount: 20
-  stepCounts:
-    0: 20
-  stepFeatures:
-    0: 20
 HLT_e12_lhloose_2mu10_L12MU10:
   eventCount: 0
 HLT_e140_lhloose_L1EM22VHI:
@@ -2680,10 +2666,6 @@ HLT_larnoiseburst_L1XE60:
     0: 6
   stepFeatures:
     0: 6
-HLT_larpebcalib_LArPEBCalib_L1RD0_BGRP11:
-  eventCount: 0
-HLT_larpebcalib_LArPEBCalib_L1RD0_EMPTY:
-  eventCount: 0
 HLT_mb_mbts_L1MBTS_1_EMPTY:
   eventCount: 0
 HLT_mb_sp_L1RD0_FILLED:
@@ -3334,6 +3316,20 @@ HLT_mu8_L1MU6:
     1: 12
     2: 13
     3: 13
+HLT_noalg_AlfaPEB_L1ALFA_ANY:
+  eventCount: 0
+HLT_noalg_CSCPEB_L1All:
+  eventCount: 20
+  stepCounts:
+    0: 20
+  stepFeatures:
+    0: 20
+HLT_noalg_CostMonDS_L1All:
+  eventCount: 20
+  stepCounts:
+    0: 20
+  stepFeatures:
+    0: 20
 HLT_noalg_L1All:
   eventCount: 20
 HLT_noalg_L1Calo:
@@ -3424,6 +3420,16 @@ HLT_noalg_L1XE70:
   eventCount: 4
 HLT_noalg_L1XE80:
   eventCount: 3
+HLT_noalg_LArPEBCalib_L1RD0_BGRP11:
+  eventCount: 0
+HLT_noalg_LArPEBCalib_L1RD0_EMPTY:
+  eventCount: 0
+HLT_noalg_SCTPEB_L1RD0_EMPTY:
+  eventCount: 0
+HLT_noalg_TilePEB_L1CALREQ1:
+  eventCount: 0
+HLT_noalg_TilePEB_L1CALREQ2:
+  eventCount: 0
 HLT_noalg_bkg_L1Bkg:
   eventCount: 0
 HLT_noalg_cosmiccalo_L1EM3_EMPTY:
@@ -3474,8 +3480,6 @@ HLT_noalg_mb_L1RD2_EMPTY:
   eventCount: 0
 HLT_noalg_zb_L1ZB:
   eventCount: 0
-HLT_sct_noise_SCTPEB_L1RD0_EMPTY:
-  eventCount: 0
 HLT_tau0_perf_ptonly_L1TAU12:
   eventCount: 15
   stepCounts:
@@ -4338,10 +4342,6 @@ HLT_tau80_mediumRNN_tracktwoMVA_tau60_mediumRNN_tracktwoMVA_L1TAU60_2TAU40:
     2: 3
     3: 3
     4: 2
-HLT_tilecalib_CIS_TilePEB_L1CALREQ1:
-  eventCount: 0
-HLT_tilecalib_laser_TilePEB_L1CALREQ2:
-  eventCount: 0
 HLT_timeburner_L1All:
   eventCount: 0
 HLT_unconvtrk0_fslrt_L1All:
diff --git a/Trigger/TrigValidation/TriggerTest/share/ref_data_v1Dev_build.ref b/Trigger/TrigValidation/TriggerTest/share/ref_data_v1Dev_build.ref
index 8c1be15d406c3ae4020e788c6e6fc07f417d1890..d2df6478d88cdad1f47d3cc415b1dd850efc9595 100644
--- a/Trigger/TrigValidation/TriggerTest/share/ref_data_v1Dev_build.ref
+++ b/Trigger/TrigValidation/TriggerTest/share/ref_data_v1Dev_build.ref
@@ -448,12 +448,6 @@ HLT_7j45_subresjesgscIS_ftf_L14J15:
     0: 7
 HLT_JetDS_j0_L1J100:
   eventCount: 0
-HLT_alfacalib_AlfaPEB_L1ALFA_ANY:
-  eventCount: 20
-  stepCounts:
-    0: 20
-  stepFeatures:
-    0: 20
 HLT_beamspot_allTE_trkfast_BeamSpotPEB_L1J15:
   eventCount: 20
   stepCounts:
@@ -470,18 +464,6 @@ HLT_beamspot_trkFS_trkfast_BeamSpotPEB_L1J15:
   stepFeatures:
     0: 20
     1: 20
-HLT_costmonitor_CostMonDS_L1All:
-  eventCount: 20
-  stepCounts:
-    0: 20
-  stepFeatures:
-    0: 20
-HLT_cscmon_CSCPEB_L1All:
-  eventCount: 20
-  stepCounts:
-    0: 20
-  stepFeatures:
-    0: 20
 HLT_e12_lhloose_2mu10_L12MU10:
   eventCount: 0
   stepFeatures:
@@ -1518,18 +1500,6 @@ HLT_j85_pf_ftf_L1J20:
     1: 3
 HLT_larnoiseburst_L1XE60:
   eventCount: 0
-HLT_larpebcalib_LArPEBCalib_L1RD0_BGRP11:
-  eventCount: 20
-  stepCounts:
-    0: 20
-  stepFeatures:
-    0: 20
-HLT_larpebcalib_LArPEBCalib_L1RD0_EMPTY:
-  eventCount: 20
-  stepCounts:
-    0: 20
-  stepFeatures:
-    0: 20
 HLT_mb_mbts_L1MBTS_1_EMPTY:
   eventCount: 9
   stepCounts:
@@ -1867,6 +1837,24 @@ HLT_mu8_L1MU6:
   stepFeatures:
     0: 1
     1: 1
+HLT_noalg_AlfaPEB_L1ALFA_ANY:
+  eventCount: 20
+  stepCounts:
+    0: 20
+  stepFeatures:
+    0: 20
+HLT_noalg_CSCPEB_L1All:
+  eventCount: 20
+  stepCounts:
+    0: 20
+  stepFeatures:
+    0: 20
+HLT_noalg_CostMonDS_L1All:
+  eventCount: 20
+  stepCounts:
+    0: 20
+  stepFeatures:
+    0: 20
 HLT_noalg_L1All:
   eventCount: 20
 HLT_noalg_L1Calo:
@@ -1957,6 +1945,36 @@ HLT_noalg_L1XE70:
   eventCount: 20
 HLT_noalg_L1XE80:
   eventCount: 20
+HLT_noalg_LArPEBCalib_L1RD0_BGRP11:
+  eventCount: 20
+  stepCounts:
+    0: 20
+  stepFeatures:
+    0: 20
+HLT_noalg_LArPEBCalib_L1RD0_EMPTY:
+  eventCount: 20
+  stepCounts:
+    0: 20
+  stepFeatures:
+    0: 20
+HLT_noalg_SCTPEB_L1RD0_EMPTY:
+  eventCount: 20
+  stepCounts:
+    0: 20
+  stepFeatures:
+    0: 20
+HLT_noalg_TilePEB_L1CALREQ1:
+  eventCount: 20
+  stepCounts:
+    0: 20
+  stepFeatures:
+    0: 20
+HLT_noalg_TilePEB_L1CALREQ2:
+  eventCount: 20
+  stepCounts:
+    0: 20
+  stepFeatures:
+    0: 20
 HLT_noalg_bkg_L1Bkg:
   eventCount: 20
 HLT_noalg_cosmiccalo_L1EM3_EMPTY:
@@ -2007,12 +2025,6 @@ HLT_noalg_mb_L1RD2_EMPTY:
   eventCount: 20
 HLT_noalg_zb_L1ZB:
   eventCount: 20
-HLT_sct_noise_SCTPEB_L1RD0_EMPTY:
-  eventCount: 20
-  stepCounts:
-    0: 20
-  stepFeatures:
-    0: 20
 HLT_tau0_perf_ptonly_L1TAU12:
   eventCount: 3
   stepCounts:
@@ -2837,18 +2849,6 @@ HLT_tau80_mediumRNN_tracktwoMVA_tau35_mediumRNN_tracktwoMVA_L1TAU60_DR-TAU20ITAU
     0: 4
 HLT_tau80_mediumRNN_tracktwoMVA_tau60_mediumRNN_tracktwoMVA_L1TAU60_2TAU40:
   eventCount: 0
-HLT_tilecalib_CIS_TilePEB_L1CALREQ1:
-  eventCount: 20
-  stepCounts:
-    0: 20
-  stepFeatures:
-    0: 20
-HLT_tilecalib_laser_TilePEB_L1CALREQ2:
-  eventCount: 20
-  stepCounts:
-    0: 20
-  stepFeatures:
-    0: 20
 HLT_timeburner_L1All:
   eventCount: 0
 HLT_unconvtrk0_fslrt_L1All:
diff --git a/Trigger/TriggerCommon/TriggerJobOpts/python/TriggerConfigFlags.py b/Trigger/TriggerCommon/TriggerJobOpts/python/TriggerConfigFlags.py
index 1e5141b328ae0d0a290d3c5c07cc800a55f1ebcc..639b04bf10b3234a8c7a80617f7396a37dc54cd7 100644
--- a/Trigger/TriggerCommon/TriggerJobOpts/python/TriggerConfigFlags.py
+++ b/Trigger/TriggerCommon/TriggerJobOpts/python/TriggerConfigFlags.py
@@ -145,7 +145,7 @@ def createTriggerFlags():
 
     # Enables collection and export of detailed monitoring data of the HLT execution
     flags.addFlag('Trigger.CostMonitoring.doCostMonitoring', False)
-    flags.addFlag('Trigger.CostMonitoring.chain', 'HLT_costmonitor_CostMonDS_L1All')
+    flags.addFlag('Trigger.CostMonitoring.chain', 'HLT_noalg_CostMonDS_L1All')
     flags.addFlag('Trigger.CostMonitoring.outputCollection', 'HLT_TrigCostContainer')
     flags.addFlag('Trigger.CostMonitoring.monitorAllEvents', False)
     flags.addFlag('Trigger.CostMonitoring.monitorROBs', False)
diff --git a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/CalibCosmicMon/CosmicChainConfiguration.py b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/CalibCosmicMon/CosmicChainConfiguration.py
index 7c3aa4e5d389a7119c77d6cc88c220970623b299..5adfbcbd6d298ff6dff733f6cc1050723f8cccd9 100644
--- a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/CalibCosmicMon/CosmicChainConfiguration.py
+++ b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/CalibCosmicMon/CosmicChainConfiguration.py
@@ -23,9 +23,6 @@ class CosmicChainConfiguration(ChainConfigurationBase):
         # define here the names of the steps and obtain the chainStep configuration 
         # --------------------
         stepDictionary = {
-            "sct_noise":[],
-            "tilecalib_laser" : [],
-            "tilecalib_CIS" : [],
         }
 
         key = self.chainPart['chainPartName']
diff --git a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/CalibCosmicMon/MonitorChainConfiguration.py b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/CalibCosmicMon/MonitorChainConfiguration.py
index 080de18c9a26f60a081bdd39a430d50ff57fa07d..dd9e0df7e2ce37f77cfc36b9007c7cab01946711 100644
--- a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/CalibCosmicMon/MonitorChainConfiguration.py
+++ b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/CalibCosmicMon/MonitorChainConfiguration.py
@@ -49,11 +49,7 @@ class MonitorChainConfiguration(ChainConfigurationBase):
         chainSteps = []
         log.debug("Assembling chain for %s", self.chainName)
 
-        if self.chainPartName == 'costmonitor':
-            pass  # costmonitor is a streamer so has no steps
-        elif self.chainPartName == 'cscmon':
-            pass
-        elif self.chainPartName == 'timeburner':
+        if self.chainPartName == 'timeburner':
             chainSteps.append(self.getTimeBurnerStep())
         else:
             raise RuntimeError('Unexpected chainPartName '+self.chainPartName+' in MonitorChainConfiguration')
diff --git a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/DictFromChainName.py b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/DictFromChainName.py
index 551a0c57befaddece6c1d110112635db6d76ce51..6f8ddd6777a47ca23aa5b73597b6c5f86f75d3f4 100755
--- a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/DictFromChainName.py
+++ b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/DictFromChainName.py
@@ -277,7 +277,7 @@ def analyseChainName(chainName, L1thresholds, L1item):
         elif cpart =='noalg':
             multichainindex.append(hltChainNameShort.index(cpart))
             buildDict( 'Streaming', 'streamer')
-            break # stop loop here so mb doesn't get picked up from min bias slice as it's streaming info
+            break # stop loop here so that further parts like noalg_idmon are discarded, this allows have copies with different output streams and prescales. Caveat: all noalg chains go into the Streaming slice
         else:
             for chainCategory in [(['mb'], 'MinBias', 'mb'),
                                   (['hi'], 'HeavyIon', 'mb'),
diff --git a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/GenerateMenuMT.py b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/GenerateMenuMT.py
index e63adcccfb65cee6d6d85e8e03a32440a86e2b7c..1d82cbac214fa7ec885081bc59d2403f9b0c0fd7 100755
--- a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/GenerateMenuMT.py
+++ b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/GenerateMenuMT.py
@@ -178,11 +178,13 @@ class GenerateMenuMT(object, metaclass=Singleton):
         # and then import them!
         log.debug("[getSignaturesInMenu] signaturesToGenerate: %s",  self.signaturesToGenerate)
 
-        for sig in self.signaturesToGenerate:
+        extendedSignatureToGenerate = self.signaturesToGenerate+['Streaming'] # always import the Streaming sig because noalg chains are moved to StreamingSlice
+
+        for sig in extendedSignatureToGenerate:
             log.debug("[getSignaturesInMenu] sig: %s", sig)
             
             try:
-                if eval('self.do' + sig + 'Chains'):
+                if eval('self.do' + sig + 'Chains') or sig=='Streaming':  
                     if sig == 'Egamma':
                         sigFolder = sig
                         subSigs = ['Electron', 'Photon']
diff --git a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/LS2_v1.py b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/LS2_v1.py
index 8924ceddda0acccbab5a9836c8034250d4b2fefa..f35cc0d5bed5b72652632937ed9ecc4e1781e8b6 100644
--- a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/LS2_v1.py
+++ b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/LS2_v1.py
@@ -656,7 +656,7 @@ def setupMenu():
         # ChainProp(name='HLT_mb_sp600_trk45_hmt_L1RD0_FILLED',        l1SeedThresholds=['FSNOSEED'], stream=[PhysicsStream], groups=MinBiasGroup),
     ]
     TriggerFlags.CalibSlice.signatures     =    TriggerFlags.CalibSlice.signatures() + [
-        ChainProp(name='HLT_alfacalib_AlfaPEB_L1ALFA_ANY', l1SeedThresholds=['FSNOSEED'], stream=['ALFACalib'], groups=['RATE:ALFACalibration','BW:Detector']),
+        ChainProp(name='HLT_noalg_AlfaPEB_L1ALFA_ANY', l1SeedThresholds=['FSNOSEED'], stream=['ALFACalib'], groups=['RATE:ALFACalibration','BW:Detector']),
     ]
     TriggerFlags.CosmicSlice.signatures    = TriggerFlags.CosmicSlice.signatures() + [
     ]
@@ -668,7 +668,7 @@ def setupMenu():
     ]
 
     TriggerFlags.MonitorSlice.signatures   = TriggerFlags.MonitorSlice.signatures() + [
-       ChainProp(name='HLT_cscmon_CSCPEB_L1All', l1SeedThresholds=['FSNOSEED'], stream=['CSC'], groups=['RATE:Monitoring','BW:Other']),
+       ChainProp(name='HLT_noalg_CSCPEB_L1All', l1SeedThresholds=['FSNOSEED'], stream=['CSC'], groups=['RATE:Monitoring','BW:Other']),
     ]
 
     # Random Seeded EB chains which select at the HLT based on L1 TBP bits
diff --git a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/PhysicsP1_HI_run3_v1.py b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/PhysicsP1_HI_run3_v1.py
index 88cd8a08301109fd685edd38b5c7e1fef3ccc9ee..3ed92d0bd9905879569d5f1930e09e30ab1fc5c4 100644
--- a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/PhysicsP1_HI_run3_v1.py
+++ b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/PhysicsP1_HI_run3_v1.py
@@ -69,7 +69,7 @@ def setupMenu():
     ]
 
     TriggerFlags.MonitorSlice.signatures   = [
-          ChainProp(name='HLT_costmonitor_CostMonDS_L1All',        l1SeedThresholds=['FSNOSEED'], stream=['CostMonitoring'], groups=['RATE:Monitoring','BW:Other']),
+          ChainProp(name='HLT_noalg_CostMonDS_L1All',        l1SeedThresholds=['FSNOSEED'], stream=['CostMonitoring'], groups=['RATE:Monitoring','BW:Other']),
     ]
 
     # Random Seeded EB chains which select at the HLT based on L1 TBP bits
diff --git a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/PhysicsP1_pp_run3_v1.py b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/PhysicsP1_pp_run3_v1.py
index fcfc56a02701921b7da411c54ec83a7fd991d957..eb02225793a6ca402ed5b4b98c48122c88859f4f 100644
--- a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/PhysicsP1_pp_run3_v1.py
+++ b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/PhysicsP1_pp_run3_v1.py
@@ -58,14 +58,14 @@ def addP1Signatures():
         ChainProp(name='HLT_mb_sp_L1RD0_FILLED', l1SeedThresholds=['FSNOSEED'], stream=[PhysicsStream], groups=['PS:Online',MinBiasGroup]),
     ]
     TriggerFlags.CalibSlice.signatures     = TriggerFlags.CalibSlice.signatures() + [
-        ChainProp(name='HLT_larpebcalib_LArPEBCalib_L1RD0_EMPTY', l1SeedThresholds=['FSNOSEED'], stream=['LArPEB'], groups=['RATE:Calibration','BW:Detector']),
-        ChainProp(name='HLT_larpebcalib_LArPEBCalib_L1RD0_BGRP11', l1SeedThresholds=['FSNOSEED'], stream=['LArPEB'], groups=['RATE:Calibration','BW:Detector']),
+        ChainProp(name='HLT_noalg_LArPEBCalib_L1RD0_EMPTY', l1SeedThresholds=['FSNOSEED'], stream=['LArPEB'], groups=['RATE:Calibration','BW:Detector']),
+        ChainProp(name='HLT_noalg_LArPEBCalib_L1RD0_BGRP11', l1SeedThresholds=['FSNOSEED'], stream=['LArPEB'], groups=['RATE:Calibration','BW:Detector']),
         ChainProp(name='HLT_larnoiseburst_L1XE60', l1SeedThresholds=['FSNOSEED'], stream=['LArNoiseBurst'], groups=['RATE:Calibration','BW:Detector']),
     ]
     TriggerFlags.CosmicSlice.signatures    = TriggerFlags.CosmicSlice.signatures() + [
-        ChainProp(name='HLT_sct_noise_SCTPEB_L1RD0_EMPTY', l1SeedThresholds=['FSNOSEED'], stream=['SCTNoise'], groups=['RATE:SCTCalibration','BW:Detector']),
-        ChainProp(name='HLT_tilecalib_laser_TilePEB_L1CALREQ2', l1SeedThresholds=['FSNOSEED'], stream=['Tile'], groups=['RATE:TileCalibration','BW:Detector']),
-        ChainProp(name='HLT_tilecalib_CIS_TilePEB_L1CALREQ1', l1SeedThresholds=['FSNOSEED'], stream=['Tile'], groups=['RATE:TileCalibration','BW:Detector'])
+        ChainProp(name='HLT_noalg_SCTPEB_L1RD0_EMPTY', l1SeedThresholds=['FSNOSEED'], stream=['SCTNoise'], groups=['RATE:SCTCalibration','BW:Detector']), # HLT_sct_noise
+        ChainProp(name='HLT_noalg_TilePEB_L1CALREQ2', l1SeedThresholds=['FSNOSEED'], stream=['Tile'], groups=['RATE:TileCalibration','BW:Detector']), # HLT_tilecalib_laser 
+        ChainProp(name='HLT_noalg_TilePEB_L1CALREQ1', l1SeedThresholds=['FSNOSEED'], stream=['Tile'], groups=['RATE:TileCalibration','BW:Detector']), # HLT_tilecalib_CIS 
     ]
     TriggerFlags.StreamingSlice.signatures = TriggerFlags.StreamingSlice.signatures() + [
         ChainProp(name='HLT_noalg_L1RD0_EMPTY',  l1SeedThresholds=['FSNOSEED'], stream=[PhysicsStream], groups=MinBiasGroup), 
diff --git a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/Physics_pp_run3_v1.py b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/Physics_pp_run3_v1.py
index e3dd8b50b990b35468f89cfcb36be11aec5f44e6..a6d386a1bf4b0dce4fcd14b1acda55ecef2678c7 100644
--- a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/Physics_pp_run3_v1.py
+++ b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/Physics_pp_run3_v1.py
@@ -172,7 +172,7 @@ def setupMenu():
     TriggerFlags.StreamingSlice.signatures = [
     ]
     TriggerFlags.MonitorSlice.signatures   = [
-        ChainProp(name='HLT_costmonitor_CostMonDS_L1All',        l1SeedThresholds=['FSNOSEED'], stream=['CostMonitoring'], groups=['RATE:Monitoring','BW:Other']),
+        ChainProp(name='HLT_noalg_CostMonDS_L1All',        l1SeedThresholds=['FSNOSEED'], stream=['CostMonitoring'], groups=['RATE:Monitoring','BW:Other']), # HLT_costmonitor
     ]
 
     # Random Seeded EB chains which select at the HLT based on L1 TBP bits
diff --git a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/SignatureDicts.py b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/SignatureDicts.py
index 4d84afd31049fc6b2110537984b223376b32538c..d3d62c45789f8b1e1a103daedf63494686eb8a8a 100644
--- a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/SignatureDicts.py
+++ b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/SignatureDicts.py
@@ -633,7 +633,6 @@ HeavyIonChainParts_Default = {
 # ---- CosmicDef chains -----
 #==========================================================
 AllowedCosmicChainIdentifiers = ['larps','larhec',
-                                 'tilecalib',
                                  'sct',  'id',]
 
 # ---- Cosmic Chain Dictionary of all allowed Values ----
@@ -719,10 +718,10 @@ StreamingChainParts_Default = {
 #==========================================================
 AllowedCalibChainIdentifiers = ['csccalib',     'larcalib',
                                 'idcalib',      'l1calocalib',
-                                'tilelarcalib', 'alfacalib',
+                                'tilelarcalib',
                                 'larnoiseburst','ibllumi',
                                 'l1satmon',     'zdcpeb',
-                                'calibAFP', 'larpebcalib',
+                                'calibAFP',
                                 ]
 
 # ---- Calib Chain Dictionary of all allowed Values ----
@@ -770,8 +769,8 @@ CalibChainParts_Default = {
 #==========================================================
 # ---- MonitorDef chains -----
 #==========================================================
-AllowedMonitorChainIdentifiers = ['robrequest', 'timeburner',  'costmonitor',
-                                  'cscmon', 'idmon',
+AllowedMonitorChainIdentifiers = ['robrequest', 'timeburner',
+                                  'idmon',
                                   'l1calooverflow', 'l1topodebug',
                                   'mistimemonl1bccorr','mistimemonl1bccorrnomu',
                                   'mistimemoncaltimenomu','mistimemoncaltime',
diff --git a/Trigger/TrigSteer/L1Decoder/src/PrescalingTool.cxx b/Trigger/TrigSteer/L1Decoder/src/PrescalingTool.cxx
index 4632db4a014fc56be8aaab34384a4390b52146b3..10828ca1ce5e1377d00e0308e0e5a05540a869c9 100644
--- a/Trigger/TrigSteer/L1Decoder/src/PrescalingTool.cxx
+++ b/Trigger/TrigSteer/L1Decoder/src/PrescalingTool.cxx
@@ -92,7 +92,7 @@ StatusCode PrescalingTool::prescaleChains( const EventContext& ctx,
          const auto & prescale = hltPrescaleSet->prescale( ch.numeric() );
          if( prescale.enabled ) {
             auto flat = engine->flat();
-            if(ch.numeric() == 843341480) { // this is to explicitly monitor the chain HLT_costmonitor_CostMonDS_L1All (hash 843341480)
+            if(ch.numeric() == 1891459708) { // this is to explicitly monitor the chain HLT_noalg_CostMonDS_L1All (hash 1891459708)
                auto mon_rndm = Monitored::Scalar<double>("Random", flat);
                Monitored::Group(m_monTool, mon_rndm);
             }